summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--perl-install/network/ethernet.pm5
1 files changed, 3 insertions, 2 deletions
diff --git a/perl-install/network/ethernet.pm b/perl-install/network/ethernet.pm
index 4d9633cd2..86d85c7c6 100644
--- a/perl-install/network/ethernet.pm
+++ b/perl-install/network/ethernet.pm
@@ -91,11 +91,12 @@ sub get_eth_cards {
my @cards = grep { my $dev = $_; every { $dev->{$_} eq $l{$_} } keys %l } detect_devices::probeall();
$description ||= $cards[0]{description} if @cards == 1;
} elsif (!$a && -e "/sys/class/net/$interface/wireless") {
# probably a rt2400/rt2500 device (PCI or PCMCIA CardBus)
# these broken drivers don't create the "device" link
# try to see if rt2400/rt2500 is loaded, and assume current wireless device uses it
# FIXME: remove this code as soon as the drivers are fixed
$a = find { -e "/sys/bus/pci/drivers/$_" } qw(rt2400 rt2500);
+ $a ||= find { -e "/sys/bus/usb/drivers/$_" } qw(zd1201);
}
}
# 6) try to match a device by driver for device description:
@@ -91,11 +91,12 @@ sub get_eth_cards {
$description ||= $cards[0]{description} if @cards == 1;
} elsif (!$a && -e "/sys/class/net/$interface/wireless") {
- # probably a rt2400/rt2500 device (PCI or PCMCIA CardBus)
+ # probably a rt2400/rt2500 device (PCI or PCMCIA CardBus) or zd1201 (USB)
# these broken drivers don't create the "device" link
@@ -91,11 +91,12 @@ sub get_eth_cards {
# these broken drivers don't create the "device" link
- # try to see if rt2400/rt2500 is loaded, and assume current wireless device uses it
+ # try to see if rt2400/rt2500/zd1201 is loaded, and assume current wireless device uses it
# FIXME: remove this code as soon as the drivers are fixed
$a = find { -e "/sys/bus/pci/drivers/$_" } qw(rt2400 rt2500);